<?xml version="1.0" ?><!DOCTYPE TS><TS language="ast" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Visor Deepin d&apos;imáxenes</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versión:</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>imáxe</translation>
    </message>
    <message>
        <source>images</source>
        <translation>imáxenes</translation>
    </message>
    <message>
        <source>album</source>
        <translation>álbum</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>álbumes</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Xestionar sincronización</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Sincronizando:</translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceutar</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Álbum nuevu</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Ensin nome</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Importóse apocayá</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Les mios favorites</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>¿De xuru que quies desaniciar esti álbum?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Lo favorito de mio</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Llinia temporal</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Amestar</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Pues amestar un direutoriu de sincronización o arrastrar y soltar les imáxenes na llinia temporal</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Ensin nome</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diapositiva</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Visor d&apos;imáxenes Deepin</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Imáxenes</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Aceutar</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>¿De xuru que quies amestar les semeyes al álbum?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Sincronizar y crear</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Sincronizar</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>¿De xuru que quies amestar al llistáu de sincronización y crear l&apos;álbum col nome d&apos;esta carpeta?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Esportóse con esitu</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Fallu al esportar</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>¿De xuru que quies tirar les semeyes a la papelera?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Información d&apos;imaxe</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Esti ficheru contién munches páxines, usa Evince pa veles toes.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diapositiva</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprentar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Desaniciar del álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorita</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Non favorita</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Voltiar a drecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Voltiar a esquierda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Afitar como fondu de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Amosar nel xestor de ficheros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información d&apos;imaxe</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Amestar</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Pues amestar un direutoriu de sincronización o arrastrar y soltar les imáxenes na llinia temporal</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Amestar al álbum</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Amestar al álbum nuevu</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Abrir direutoriu</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Nun tienes permisu pa ver la imaxe</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Triba</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Data de modificación</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File size</source>
        <translation>Tamañu de ficheru</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espaciu de colores</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Mou d&apos;esposición</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa d&apos;esposición</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Tiempu d&apos;esposición</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flax</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Apertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Llonxitú focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Apertura máx.</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mou de midición</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balance de blancos</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensación de flax</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Modélu de cámara</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Modelu de lente</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Axustar páxina a la imaxe</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Axustar imaxe a la páxina</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Escalar a:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milímetros</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centímetros</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Pulgaes</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Escaláu</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Conmutador</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Eslizante</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Aniellu</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Esbillar direutoriu</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Esti direutoriu tien desactivao&apos;l sincronizar</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Amestar carpeta</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Xestión de direutorios de sincronización</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>El llistáu de direutorios ta baleru</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Encaboxar sincronización</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imáxenes</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Estráxose&apos;l preséu</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Esti direutoriu yá nun esiste</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Calculando...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Visión d&apos;imáxenes</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diapositiva</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Finar presentación</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Desaniciar del álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorita</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Non favorita</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Voltiar a drecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Voltiar a esquierda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Afitar como fondu de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Amosar nel xestor de ficheros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información d&apos;imaxe</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Pantalla previa</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Pantalla siguiente</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Álbum nuevu</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomar</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Colar</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Amosar atayos</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Introduz un atayu nuevu, por favor</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Atayos</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Ver semeya</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Reafitar valores</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Diapositiva</translation>
    </message>
    <message>
        <source>End show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprentar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Desaniciar del álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorita</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Non favorita</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Voltiar a drecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Voltiar a esquierda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Afitar como fondu de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Amosar nel xestor de ficheros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información d&apos;imaxe</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Álbum nuevu</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renomar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Posar/Reproducir</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Camudar efeutu</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Camudar duración</translation>
    </message>
    <message>
        <source>second</source>
        <translation>segundu</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Xestión d&apos;imáxenes</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Lo favorito de mio</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Tamañu 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Axustar a la ventana</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Voltiar a esquierda</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Voltiar a drecha</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>Nun s&apos;alcontraron imáxenes</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 imaxe</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 imáxenes</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Xestionar sincronización</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Sincronizando:</translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Amestar</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Pues amestar un direutoriu de sincronización o arrastrar y soltar les imáxenes na llinia temporal</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Amestar al álbum</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Amestar al álbum nuevu</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprentar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copiar al cartafueyu</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorita</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Non favorita</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Voltiar a drecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Voltiar a esquierda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Afitar como fondu de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Amosar nel xestor de ficheros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Información d&apos;imaxe</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Effect</source>
        <translation>Efeutu</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Duración</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Atayos</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Álbum</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>dd MMMM yyyy</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Lo favorito de mio</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Importóse apocayá</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Álbum nuevu</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>El visor Deepin d&apos;imáxenes ye un visor d&apos;imáxenes modernu y suave.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Tien como carauterístiques la xestión, visión y edición básica d&apos;imáxenes.</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Tema prietu</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Llinia temporal</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Amestar al álbum</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Amestar al álbum nuevu</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Colar de pantalla completa</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprentar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Desaniciar del álbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorita</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Non favorita</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Amosar ventana de navegación</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Anubrir ventana de navegación</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Voltiar a drecha</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Voltiar a esquierda</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Afitar como fondu de pantalla</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Amosar nel xestor de ficheros</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>información d&apos;imaxe</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>All images</source>
        <translation>Toles imáxenes</translation>
    </message>
</context>
</TS>